==> cdi-tck-2.0.6-dist.zip: org/jboss/cdi/tck/tests/decorators/invocation/producer/method/ProducerImpl.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2010, Red Hat, Inc., and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,  
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.cdi.tck.tests.decorators.invocation.producer.method;

import javax.enterprise.inject.Disposes;
import javax.enterprise.inject.Produces;

/**
 * @author pmuir
 * 
 */
public class ProducerImpl implements Producer {

    private static boolean disposedCorrectly = false;

    /**
     * @param log the log to set
     */
    public static void reset() {
        disposedCorrectly = false;
    }

    @Produces
    public Foo produce() {
        return new Foo("foo!");
    }

    public void dispose(@Disposes Foo foo) {
        disposedCorrectly = foo.getFoo().equals("decorated");
    }

    /**
     * @return the disposedCorrectly
     */
    public static boolean isDisposedCorrectly() {
        return disposedCorrectly;
    }

}

==> cdi-tck-3.0.1-dist.zip: org/jboss/cdi/tck/tests/decorators/invocation/producer/method/ProducerImpl.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2010, Red Hat, Inc., and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,  
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.cdi.tck.tests.decorators.invocation.producer.method;

import jakarta.enterprise.inject.Disposes;
import jakarta.enterprise.inject.Produces;

/**
 * @author pmuir
 * 
 */
public class ProducerImpl implements Producer {

    private static boolean disposedCorrectly = false;

    /**
     * @param log the log to set
     */
    public static void reset() {
        disposedCorrectly = false;
    }

    @Produces
    public Foo produce() {
        return new Foo("foo!");
    }

    public void dispose(@Disposes Foo foo) {
        disposedCorrectly = foo.getFoo().equals("decorated");
    }

    /**
     * @return the disposedCorrectly
     */
    public static boolean isDisposedCorrectly() {
        return disposedCorrectly;
    }

}
